@@ -5,16 +5,16 @@ from urllib.parse import urlparse, urlunparse, urljoin
 
 import pytest
 from box import Box
-from faker import Faker
 
 from framework.exit_code import ExitCode
 from framework.db.redis_db import RedisDB
+from framework.db.mysql_db import MysqlDB
 from framework.utils.log_util import logger
 from framework.render_data import RenderData
 from framework.http_client import ResponseUtil
+from framework.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 from framework.utils.common import snake_to_pascal, SingletonFaker
 from framework.global_attribute import CONFIG, GlobalAttribute, _FRAMEWORK_CONTEXT
-from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 
 module = importlib.import_module("test_case.conftest")
 
@@ -36,7 +36,6 @@ class BaseTestCase(object):
             app_http = getattr(self.http, app)
             domain = self.context.get(app).get("domain")
             data = RenderData(data).render()
-            url = data.request.get("url")
             data.request.url = self.replace_domain(data.request.url, domain)
             self.response = getattr(app_http, account).request(data=data, kwargs=kwargs)
             if self.response.status_code in UNAUTHORIZED_CODE:
@@ -76,16 +75,16 @@ class BaseTestCase(object):
         request.update({"method": "delete", "headers": {}, **kwargs})
         return self.request(app=app, account=account, data=Box({"request": request}))
 
-    def mysql_conn(self, db, app=None):
+    def mysql_conn(self, db, app=None) -> MysqlDB:
         try:
             return _FRAMEWORK_CONTEXT.get(app=self.default_app(app), key="mysql").get(db)
         except AttributeError as e:
             traceback.print_exc()
             pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
 
-    def redis_conn(self, db, app=None):
+    def redis_conn(self, db, index=0, app=None) -> RedisDB:
         try:
-            return RedisDB(**CONFIG.get(app=self.default_app(app), key="redis").get(db))
+            return _FRAMEWORK_CONTEXT.get(app=self.default_app(app), key="redis").get(db)[index]
         except AttributeError as e:
             traceback.print_exc()
             pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
