@@ -17,6 +17,7 @@ import retry
 import allure
 import pytest
 from box import Box
+import simplejson as json
 
 from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
@@ -399,7 +400,7 @@ def pytest_runtest_setup(item):
         test_object.http = _FRAMEWORK_CONTEXT.get(key="_http")
         data = item.callspec.params.get("data")
         test_object.data = Box(data)
-        test_object.scenario = Box(convert_numbers_to_decimal(data.get("_scenario").get("data")))
+        test_object.scenario = Box(json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario").get("data")))))
         test_object.belong_app = data.get("_belong_app")
         test_before_scenario = getattr(test_object, "test_setup", None)
         if test_before_scenario:
@@ -456,7 +457,7 @@ def pytest_runtest_call(item):
     http = item.funcargs.get("http")
     item.funcargs["data"] = item.instance.data = Box(origin_data)
     item.funcargs["scenario"] = item.instance.scenario = Box(
-        convert_numbers_to_decimal(origin_data.get("_scenario").get("data")))
+        json.loads(json.dumps(convert_numbers_to_decimal(origin_data.get("_scenario").get("data")))))
     _belong_app = origin_data.get("_belong_app")
     item.funcargs["belong_app"] = item.instance.belong_app = _belong_app
     item.funcargs["config"] = item.instance.config = CONFIG
